/* $Header: /cvs/gnome/gIDE/src/gI_prefs.h,v 1.3 2000/04/19 12:51:32 jpr Exp $ */
/* gIDE
 * Copyright (C) 1998-2000 Steffen Kern
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GI_PREFS_H
#define GI_PREFS_H

#include <gtk/gtk.h>

/*
 * Prototypes for 'gI_prefs.c'
 */
void show_preferences( GtkWidget *widget, gpointer data );
void set_to_defaults( GtkWidget *widget, gpointer data );
void reload_config( GtkWidget *widget, gpointer data );
gI_comp_dialog *gI_comp_dialog_new(void);
gI_comp_set *gI_comp_set_get( gchar *cset );

#endif

